nelsonaalen_npdf: Nelson-Aalen estimates of group-specific cumulative hazard from a nonparametric discrete frailty model
Description
Nelson-Aalen estimates of group-specific cumulative hazard from a nonparametric discrete frailty model
Usage
nelsonaalen_npdf(x)
Value
A list of objects of length equal to the number of groups in the data. Each component is a list, equivalent to the output of survfit called for the corresponding group with type="fh", but with two additional components:
y0: -log of the survival estimate
sfun0: a step function for y0 in terms of time, estimated using stepfun.
Arguments
x
A fitted nonparametric discrete frailty model, as returned by npdf_cox with estK=FALSE.