Prints the model comparison statistics comparing models with different numbers of latent populations, and prints the estimates from the optimal model according to the criterion that was specified when calling npdf_cox (by default, BIC criterion).
# S3 method for npdflist
print(x, digits = NULL, ...)An object returned by npdf_cox with estK=TRUE, containing a list of fitted nonparametric discrete frailty models
Number of significant digits to present, by default max(1, getOption("digits") - 4)
Further options (currently unused)